summaryrefslogtreecommitdiffstats
path: root/kmymoney2/widgets/kmymoneycombo.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit902ba103f2215bcefa22d62b1c9138aa4b88891c (patch)
tree63ef88424b9be33a31e5a8de61343fb8d7633937 /kmymoney2/widgets/kmymoneycombo.h
parent7e51b6d5ddc01fc3bc69f30bc5d3933a7709dbf2 (diff)
downloadkmymoney-902ba103f2215bcefa22d62b1c9138aa4b88891c.tar.gz
kmymoney-902ba103f2215bcefa22d62b1c9138aa4b88891c.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/kmymoney@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kmymoney2/widgets/kmymoneycombo.h')
-rw-r--r--kmymoney2/widgets/kmymoneycombo.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/kmymoney2/widgets/kmymoneycombo.h b/kmymoney2/widgets/kmymoneycombo.h
index f889f3e..32f4ec5 100644
--- a/kmymoney2/widgets/kmymoneycombo.h
+++ b/kmymoney2/widgets/kmymoneycombo.h
@@ -332,7 +332,7 @@ private:
* If any match is found a list selection box is opened and the user can use
* the up/down, page-up/page-down keys or the mouse to navigate in the list. If
* a payee is selected, the selection box is closed. Other key-strokes are
* directed to the tqparent object to manipulate the text. The visible contents of
* the selection box is updated with every key-stroke.
*
* This object is a replacement of the kMyMoneyPayee object and should be used
@@ -345,7 +345,7 @@ class KMyMoneyPayeeCombo : public KMyMoneyCombo
Q_OBJECT
TQ_OBJECT
public:
- KMyMoneyPayeeCombo(TQWidget* tqparent = 0, const char* name = 0);
+ KMyMoneyPayeeCombo(TQWidget* parent = 0, const char* name = 0);
void loadPayees(const TQValueList<MyMoneyPayee>& list);
};
@@ -355,7 +355,7 @@ class KMyMoneyGeneralCombo : public KComboBox
Q_OBJECT
TQ_OBJECT
public:
- KMyMoneyGeneralCombo(TQWidget* tqparent = 0, const char* name = 0);
+ KMyMoneyGeneralCombo(TQWidget* parent = 0, const char* name = 0);
virtual ~KMyMoneyGeneralCombo();
void insertItem(const TQString& txt, int id, int idx = -1);
@@ -398,7 +398,7 @@ class KMyMoneyPeriodCombo : public KMyMoneyGeneralCombo
Q_OBJECT
TQ_OBJECT
public:
- KMyMoneyPeriodCombo(TQWidget* tqparent = 0, const char* name = 0);
+ KMyMoneyPeriodCombo(TQWidget* parent = 0, const char* name = 0);
MyMoneyTransactionFilter::dateOptionE currentItem(void) const;
void setCurrentItem(MyMoneyTransactionFilter::dateOptionE id);
@@ -422,7 +422,7 @@ public:
/**
* This class implements an occurence selector
* as a tqparent class for both OccurencePeriod and Frequency combos
*
* @author Colin Wright
*/
@@ -431,7 +431,7 @@ class KMyMoneyOccurenceCombo : public KMyMoneyGeneralCombo
Q_OBJECT
TQ_OBJECT
public:
- KMyMoneyOccurenceCombo(TQWidget* tqparent = 0, const char* name = 0);
+ KMyMoneyOccurenceCombo(TQWidget* parent = 0, const char* name = 0);
MyMoneySchedule::occurenceE currentItem(void) const;
};
@@ -446,7 +446,7 @@ class KMyMoneyOccurencePeriodCombo : public KMyMoneyOccurenceCombo
Q_OBJECT
TQ_OBJECT
public:
- KMyMoneyOccurencePeriodCombo(TQWidget* tqparent = 0, const char* name = 0);
+ KMyMoneyOccurencePeriodCombo(TQWidget* parent = 0, const char* name = 0);
};
/**
@@ -458,7 +458,7 @@ class KMyMoneyFrequencyCombo : public KMyMoneyOccurenceCombo
Q_OBJECT
TQ_OBJECT
public:
- KMyMoneyFrequencyCombo(TQWidget* tqparent = 0, const char* name = 0);
+ KMyMoneyFrequencyCombo(TQWidget* parent = 0, const char* name = 0);
/**
* This method returns the number of events for the selected payment
@@ -332,7 +332,7 @@ private:
* the up/down, page-up/page-down keys or the mouse to navigate in the list. If
* a payee is selected, the selection box is closed. Other key-strokes are
- * directed to the tqparent object to manipulate the text. The visible contents of
+ * directed to the parent object to manipulate the text. The visible contents of
* the selection box is updated with every key-stroke.
*
@@ -422,7 +422,7 @@ public:
/**
* This class implements an occurence selector
- * as a tqparent class for both OccurencePeriod and Frequency combos
+ * as a parent class for both OccurencePeriod and Frequency combos
*
* @author Colin Wright